@@ -37,7 +37,6 @@ using std::string;
 
 #include "main.h"
 #include "client.h"
-#include "registry.h"
 
 #include "gpgex.h"
 
@@ -392,9 +391,7 @@ static int
 readDefaultEntry ()
 {
   TRACE_BEG0 (DEBUG_CONTEXT_MENU, __func__, nullptr, "read default entry");
-  char *entry = read_w32_registry_string (NULL,
-                                          GPG4WIN_REGKEY_2,
-                                          "GpgExDefault");
+  char *entry = gpgrt_w32_reg_get_string ("\\Software\\Gpg4win:GpgExDefault");
   if (!entry)
     {
       return -1;
@@ -630,44 +627,6 @@ gpgex_t::GetCommandString (UINT_PTR idCommand, UINT uFlags, LPUINT lpReserved,
 }
 
 
-/* Return the lang name.  This is either "xx" or "xx_YY".  On error
-   "en" is returned.  */
-static const char *
-get_lang_name (void)
-{
-  static char *name;
-  const char *s;
-  char *p;
-  int count = 0;
-
-  if (!name)
-    {
-      s = gettext_localename ();
-      if (!s)
-        s = "en";
-      else if (!strcmp (s, "C") || !strcmp (s, "POSIX"))
-        s = "en";
-
-      name = strdup (s);
-      if (!name)
-        return "en";
-
-      for (p = name; *p; p++)
-        {
-
-          if (*p == '.' || *p == '@' || *p == '/' /*(safeguard)*/)
-            *p = 0;
-          else if (*p == '_')
-            {
-              if (count++)
-                *p = 0;  /* Also cut at a underscore in the territory.  */
-            }
-        }
-    }
-
-  return name;
-}
-
 
 /* Show the version informatione etc.  */
 static void
